@@ -18,6 +18,7 @@
 # Authors:  Ralph Bean <rbean@redhat.com>
 #
 
+import six
 import zmq
 import logging
 import inspect
@@ -158,6 +159,9 @@ def dict_query(dic, query):
 
     """
 
+    if not isinstance(query, six.string_types):
+        raise ValueError("query must be a string, not %r" % type(query))
+
     def _browse(tokens, d):
         """ Recurse through a dict to retrieve a value. """
         current, rest = tokens[0], tokens[1:]
